//	FilePropertiesDialog.h - Dialog displaying some information about a file
//							 or directory.
//	--------------------------------------------------------------------------
//	This file is part of 'Phil', a very simple file manager/browser for the
//	JUCE library.
//	Copyright (C) 2005-2006  Niall Moody
//	
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//	
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//	
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//	
//	--------------------------------------------------------------------------

#ifndef FILEPROPERTIESDIALOG_H_
#define FILEPROPERTIESDIALOG_H_

//----------------------------------------------------------------------------
///	Dialog displaying some information about a file or directory.
class FilePropertiesDialog : public DialogWindow
{
  public:
	///	Constructor.
	/*!
		\param file The file/directory to display information about.
		\param backgroundColour The colour to fill the background of the
		dialog.
	 */
	FilePropertiesDialog(const File& file, const Colour& backgroundColour);
	///	Destructor.
	~FilePropertiesDialog();

	///	Called when the user clicks the close button.
	void closeButtonPressed();

	juce_UseDebuggingNewOperator
};

//----------------------------------------------------------------------------
///	Content Component for FilePropertiesDialog.
class PropertiesContents : public Component
{
  public:
	///	Constructor.
	PropertiesContents(const File& file);
	///	Destructor.
	~PropertiesContents();

	///	Called to resize and place the various child Components.
	void resized();

	juce_UseDebuggingNewOperator
  private:
	///	The full path of the file.
	Label *filePath;
	///	The size of the file.
	Label *fileSize;
	///	The size of the free space on the file's hard disk/volume.
	Label *fileFreeSize;
	///	Whether the user has write access for the file.
	Label *fileWriteAccess;
	///	The last time the file was modified.
	Label *fileModifiedTime;
	///	The last time the file was accessed.
	Label *fileAccessedTime;
	///	When the file was created.
	Label *fileCreationTime;
};

#endif
