//	PhilChooserStatusbar.cpp - TextEditor and buttons for the PhilChooser
//							 Component.
//	--------------------------------------------------------------------------
//	This file is part of 'Phil', a very simple file manager/browser for the
//	JUCE library.
//	Copyright (C) 2005-2006  Niall Moody
//	
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//	
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//	
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//	
//	--------------------------------------------------------------------------

#include <juce.h>
#include "PhilChooserStatusbar.h"
#include "PhilComponent.h"

//----------------------------------------------------------------------------
PhilChooserStatusbar::PhilChooserStatusbar(Phil *parentComponent):
Component(),
parent(parentComponent)
{
	long i;
	String tempstr;
	const StringArray& extensions = parent->getVisibleExtensions();

	parent->addChangeListener(this);

	addAndMakeVisible(fileNameLabel = new Label(T("filenameLabel"),
												T("File name:")));
	addAndMakeVisible(fileName = new TextEditor());
	fileName->addListener(this);
	fileName->setColours(Colours::black,
						 Colours::white,
						 Colours::lightblue,
						 Colours::grey);

	addAndMakeVisible(wildcardLabel = new Label(T("wildcardLabel"),
												T("File extension:")));
	addAndMakeVisible(wildcards = new ComboBox(T("wildcard")));
	for(i=0;i<extensions.size();++i)
	{
		tempstr = T("*.");
		tempstr << extensions[i];
		wildcards->addItem(tempstr, (i+1));
	}
	wildcards->setSelectedId(1);
	wildcards->addListener(this);

	addAndMakeVisible(ok = new TextButton(T("Ok")));
	ok->addButtonListener(this);
	addAndMakeVisible(cancel = new TextButton(T("Cancel")));
	cancel->addButtonListener(this);
}

//----------------------------------------------------------------------------
PhilChooserStatusbar::~PhilChooserStatusbar()
{
	deleteAllChildren();
}

//----------------------------------------------------------------------------
void PhilChooserStatusbar::resized()
{
	fileNameLabel->setBounds(2, 2, 105, 22);
	fileName->setBounds(109, 2, (getWidth()-(109+104)), 22);
	wildcardLabel->setBounds(2, 26, 105, 22);
	wildcards->setBounds(109, 26, (getWidth()-(109+104)), 22);
	ok->setBounds((getWidth()-102), 2, 100, 22);
	cancel->setBounds((getWidth()-102), 26, 100, 22);
}

//----------------------------------------------------------------------------
void PhilChooserStatusbar::changeListenerCallback(void *objectThatHasChanged)
{
	if(objectThatHasChanged == parent)
	{
		const StringArray& selected = parent->getCurrentlyHighlightedFiles();

		if(selected.size() > 0)
			fileName->setText(File(selected[0]).getFileName());
		else
			fileName->setText(T(""));
	}
}

//----------------------------------------------------------------------------
void PhilChooserStatusbar::comboBoxChanged(ComboBox *box)
{
	if(box == wildcards)
		parent->setVisibleExtension(wildcards->getSelectedId()-1);
}

//----------------------------------------------------------------------------
void PhilChooserStatusbar::buttonClicked(Button *button)
{
	if(button == ok)
	{
		selectedFile = fileName->getText();
		sendChangeMessage(this);
	}
	else if(button == cancel)
	{
		selectedFile = String::empty;
		sendChangeMessage(this);
	}
}

//----------------------------------------------------------------------------
void PhilChooserStatusbar::textEditorReturnKeyPressed(TextEditor &editor)
{
	if(&editor == fileName)
	{
		selectedFile = fileName->getText();
		sendChangeMessage(this);
	}
}
