//	RunExternalProgram.cpp - Class for running external programs.
//	--------------------------------------------------------------------------
//	This file is part of 'Phil', a very simple file manager/browser for the
//	JUCE library.
//	Copyright (C) 2005-2006  Niall Moody
//	
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//	
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//	
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//	
//	--------------------------------------------------------------------------

#ifdef WIN32
#include "windows.h"
#endif

#include <juce.h>
#include "RunExternalProgram.h"

#ifdef JUCE_MAC
#include "ApplicationServices/ApplicationServices.h"
#endif

//----------------------------------------------------------------------------
bool ExternalProgram::run(const String& name)
{
	bool retval = false;

#ifdef WIN32
	STARTUPINFO si = {sizeof(STARTUPINFO)};
	PROCESS_INFORMATION pi = {0};

	retval = CreateProcess(NULL,
						   (char *)((const char *)name),
						   NULL,
						   NULL,
						   false,
						   NORMAL_PRIORITY_CLASS,
						   NULL,
						   NULL,
						   &si,
						   &pi) != 0;

	CloseHandle(pi.hThread);
	CloseHandle(pi.hProcess);
#elif defined(JUCE_MAC)
	String appstr;
	FSRef appRef;
	String filestr;
	FSRef fileRef;
	LSLaunchFSRefSpec tempLaunch;

	appstr = name.upToFirstOccurrenceOf(T(" "), false, false);
	if(PlatformUtilities::makeFSRefFromPath(&appRef, appstr))
		tempLaunch.appRef = &appRef;
	else
		retval = false;
	filestr = name.fromFirstOccurrenceOf(T(" "), false, false);
	if(PlatformUtilities::makeFSRefFromPath(&fileRef, filestr))
	{
		tempLaunch.numDocs = 1;
		tempLaunch.itemRefs = &fileRef;
	}
	else

	{
		tempLaunch.numDocs = 1;
		retval = false;
	}
	tempLaunch.passThruParams = NULL;
	tempLaunch.launchFlags = kLSLaunchDefaults;
	tempLaunch.asyncRefCon = NULL;

	if(LSOpenFromRefSpec(&tempLaunch, NULL) == 0)
		retval = true;
#elif defined(LINUX)
	pid_t pid = fork();

	switch (pid)
	{
		case 0: //Child process - successful.
			setsid();
			execlp("/bin/sh", "sh", "-c", (const char *)name, NULL);
			//Only get to this point if execlp didn't work.
			break;
		case -1: //Parent process - unsuccessful.
			break;
		default: //Parent process - successful.
			retval = true;
			break;
	}
#endif

	return retval;
}
